/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __ACTIONNAMES_H__
#define __ACTIONNAMES_H__

// the order is important
char * ActionName[] =
{
  "INVALID_CALL",
  "NPN_Version",
  "NPN_GetURLNotify",
  "NPN_GetURL",
  "NPN_PostURLNotify",
  "NPN_PostURL",
  "NPN_RequestRead",
  "NPN_NewStream",
  "NPN_Write",
  "NPN_DestroyStream",
  "NPN_Status",
  "NPN_UserAgent",
  "NPN_MemAlloc",
  "NPN_MemFree",
  "NPN_MemFlush",
  "NPN_ReloadPlugins",
  "NPN_GetJavaEnv",
  "NPN_GetJavaPeer",
  "NPN_GetValue",
  "NPN_SetValue",
  "NPN_InvalidateRect",
  "NPN_InvalidateRegion",
  "NPN_ForceRedraw",
  "NPP_New",
  "NPP_Destroy",
  "NPP_SetWindow",
  "NPP_NewStream",
  "NPP_DestroyStream",
  "NPP_StreamAsFile",
  "NPP_WriteReady",
  "NPP_Write",
  "NPP_Print",
  "NPP_HandleEvent",
  "NPP_URLNotify",
  "NPP_GetJavaClass",
  "NPP_GetValue",
  "NPP_SetValue"
};

#endif
